@@ -1,7 +1,7 @@
 from typing import List
 
 from bigeye_sdk.client.datawatch_client import DatawatchClient
-from bigeye_sdk.generated.com.torodata.models.generated import MetricConfiguration, MetricCreationState
+from bigeye_sdk.generated.com.bigeye.models.generated import MetricConfiguration, MetricCreationState
 
 
 def delete_metrics(client: DatawatchClient, metrics: List[MetricConfiguration]):
